@@ -26,6 +26,7 @@ export const actions = {
 	DELETE_FOLDER: 'DELETE_FOLDER',
 
 	MOVE_SELECTION: 'MOVE_SELECTION',
+	DELETE_SELECTION: 'DELETE_SELECTION',
 
 	RELOAD_VIEW: 'RELOAD_VIEW',
 
@@ -277,7 +278,6 @@ export default {
 			})
 	},
 	[actions.LOAD_TAGS]({ commit, dispatch, state }, link) {
-		if (state.loading.bookmarks) return
 		commit(mutations.FETCH_START, { type: 'tags' })
 		return axios
 			.get(url('/tag'), { params: { count: true } })
@@ -320,11 +320,17 @@ export default {
 	},
 
 	[actions.LOAD_FOLDERS]({ commit, dispatch, state }) {
-		if (state.loading.bookmarks) return
-		commit(mutations.FETCH_START, { type: 'folders' })
+		let canceled = false
+		commit(mutations.FETCH_START, {
+			type: 'folders',
+			cancel: () => {
+				canceled = true
+			}
+		})
 		return axios
 			.get(url('/folder'), { params: {} })
 			.then(response => {
+				if (canceled) return
 				const {
 					data: { data, status }
 				} = response
@@ -451,6 +457,27 @@ export default {
 			commit(mutations.FETCH_END, 'moveSelection')
 		}
 	},
+	async [actions.DELETE_SELECTION]({ commit, dispatch, state }) {
+		commit(mutations.FETCH_START, { type: 'deleteSelection' })
+		try {
+			for (const folder of state.selection.folders) {
+				await dispatch(actions.DELETE_FOLDER, folder.id)
+			}
+
+			for (const bookmark of state.selection.bookmarks) {
+				await dispatch(actions.DELETE_BOOKMARK, { id: bookmark.id })
+			}
+		} catch (err) {
+			console.error(err)
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t('bookmarks', 'Failed to delete parts of selection')
+			)
+			throw err
+		} finally {
+			commit(mutations.FETCH_END, 'deleteSelection')
+		}
+	},
 
 	[actions.RELOAD_VIEW]({ state, dispatch, commit }) {
 		commit(mutations.SET_QUERY, state.fetchState.query)
@@ -528,10 +555,13 @@ export default {
 			})
 	},
 
-	[actions.SET_SETTING]({ commit, dispatch, state }, { key, value }) {
-		commit(mutations.SET_SETTING, key, value)
-		if (key === 'viewMode' && state.viewMode !== value) {
-			commit(mutations.SET_VIEW_MODE, value)
+	async [actions.SET_SETTING]({ commit, dispatch, state }, { key, value }) {
+		await commit(mutations.SET_SETTING, { key, value })
+		if (key === 'viewMode') {
+			await commit(mutations.SET_VIEW_MODE, value)
+		}
+		if (key === 'sorting') {
+			await commit(mutations.RESET_PAGE)
 		}
 		return axios
 			.post(url(`/settings/${key}`), {
@@ -549,13 +579,16 @@ export default {
 	[actions.LOAD_SETTING]({ commit, dispatch, state }, key) {
 		return axios
 			.get(url(`/settings/${key}`))
-			.then(response => {
+			.then(async response => {
 				const {
 					data: { [key]: value }
 				} = response
-				commit(mutations.SET_SETTING, { key, value })
-				if (key === 'viewMode' && state.viewMode !== value) {
-					commit(mutations.SET_VIEW_MODE, value)
+				await commit(mutations.SET_SETTING, { key, value })
+				if (key === 'viewMode') {
+					await commit(mutations.SET_VIEW_MODE, value)
+				}
+				if (key === 'sorting') {
+					await commit(mutations.RESET_PAGE)
 				}
 			})
 			.catch(err => {
